#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['aiosubpub']

package_data = \
{'': ['*']}

extras_require = \
{'dev': ['pytest-cov', 'coverage[toml]>=5.0.3', 'pre-commit', 'pylint'],
 'test': ['pytest==5.3.5', 'pytest-asyncio==0.10.0']}

setup(name='aiosubpub',
      version='1.0.9',
      description='Aio sub pub package.',
      author='Sander Teunissen',
      author_email='no_mail@nomail.com',
      url='https://github.com/sander76/pypubsub',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='>=3.7',
     )
